--- title: anabel.graphics summary: template: pdoc.html ...

## Functions

`def plot_displ(model, displ, ax=None, fig=None, scale=None, color=None, chords=False, **kwds)`

  Claudio Perez 2021-04-02

`def plot_moments(state: object, ax=None, scale: float = None, color: str = None, chords: bool = False)`

  Plot moment distribution from a frame model analysis.

  Only works for 2D models.

`def plot_skeletal(Model, ax=None, label=False)`